Data
=================

.. automodule:: miml.data
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   miml.data.bag
   miml.data.instance
   miml.data.miml_dataset
